import { SFCDescriptor } from '@vue/component-compiler-utils';
import { BlockPlugin, ComponentRewriterAPI, CustomBlock, CustomFile, FilePlugin, FileRewriterAPI, MessageBagAPI, Plugin, ProcessedResults } from "./api";
export declare class MessageBag implements MessageBagAPI {
    errors: Array<string | Error>;
    tips: string[];
    scope: string;
    constructor();
    setScope(name: string): void;
    error(error: Error | string): void;
    tip(tip: string): void;
    hasError(): boolean;
    write(): ProcessedResults;
}
export declare class FileRewriter extends MessageBag implements FileRewriterAPI {
    input: CustomFile;
    output: {
        filename?: string;
        content?: string;
    };
    constructor(input: CustomFile);
    name(filename: string): void;
    content(content: string): void;
    write(): ProcessedResults;
}
export declare class ComponentRewriter extends MessageBag implements ComponentRewriterAPI {
    static CONSTANTS: {
        properties: Set<string>;
    };
    private mixins;
    private properties;
    private hooks;
    private currentPluginName;
    filename: string | undefined;
    descriptor: SFCDescriptor;
    blocks: CustomBlock[];
    isFunctional: boolean;
    constructor(filename: string | undefined, descriptor: SFCDescriptor);
    forEach(callback: (block: CustomBlock) => Promise<void>): Promise<void>;
    defineInstanceProperty(name: string, value: string): void;
    defineOption(name: string, value: string): void;
    defineHook(name: string, value: string): void;
    block(block: CustomBlock): void;
    createBlock(type: string, attrs: {
        [key: string]: string;
    }, code?: string): void;
    addBlock(block: CustomBlock | string, attrs?: {
        [p: string]: string;
    }, content?: string): void;
    write(): ProcessedResults;
}
export declare function compile(filename: string, content: string, plugins: Array<Plugin | BlockPlugin | FilePlugin>): Promise<ProcessedResults>;
