"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const babel_core_1 = require("babel-core");
const promised_1 = require("@znck/promised");
class BabelPlugin {
    constructor() {
        this.name = 'babel';
        this.EXT_REGEX = /\.js$/i;
        this.TYPE_REGEX = /^(js|babel|javascript)$/i;
    }
    testBlock(type, srcOrLang) {
        return type === 'script' &&
            (srcOrLang === undefined || this.EXT_REGEX.test(srcOrLang) || this.TYPE_REGEX.test(srcOrLang));
    }
    processBlock(block, api) {
        return __awaiter(this, void 0, void 0, function* () {
            if ('src' in block.attrs) {
                api.addBlock('script', block.attrs);
                return;
            }
            api.addBlock('script', block.attrs, yield this.compile(block.filename, block.content));
        });
    }
    testFile(filename) {
        return this.EXT_REGEX.test(filename);
    }
    processFile(file, api) {
        return __awaiter(this, void 0, void 0, function* () {
            api.content(yield this.compile(file.filename, file.content));
        });
    }
    compile(filename, source) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield promised_1.default({ transform: babel_core_1.transform }).transform(source, {
                filename,
                presets: [[require.resolve('@babel/preset-env'), { modules: false, loose: true }]],
                comments: false
            });
            return result.code;
        });
    }
}
exports.default = BabelPlugin;
