"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class LessPlugin {
    constructor() {
        this.EXT_REGEX = /\.less$/i;
    }
    testFile(filename) {
        return this.EXT_REGEX.test(filename);
    }
    processFile(file, api) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                api.name(file.filename.replace(this.EXT_REGEX, '.css'));
                api.content(yield this.compile(file.filename, file.content));
            }
            catch (e) {
                api.error(e);
            }
        });
    }
    testBlock(type, srcOrLang) {
        return !!(type === 'style' && srcOrLang && (srcOrLang === 'less' || this.EXT_REGEX.test(srcOrLang)));
    }
    processBlock(block, api) {
        return __awaiter(this, void 0, void 0, function* () {
            if ('src' in block.attrs) {
                block.attrs.src = block.attrs.src.replace(this.EXT_REGEX, '.css');
                api.addBlock('style', block.attrs);
                return;
            }
            try {
                api.addBlock('style', block.attrs, yield this.compile(block.filename, block.content));
            }
            catch (e) {
                api.error(e);
            }
        });
    }
    compile(filename, content) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield require('less').render(content, { filename });
            return result.css;
        });
    }
}
exports.default = LessPlugin;
