"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const promised_1 = require("@znck/promised");
class SassPlugin {
    constructor() {
        this.EXT_REGEX = /\.(scss|sass)$/i;
    }
    testFile(filename) {
        return this.EXT_REGEX.test(filename);
    }
    processFile(file, api) {
        return __awaiter(this, void 0, void 0, function* () {
            const isIndented = file.filename.endsWith('.sass');
            try {
                const result = yield this.compile(file.content, file.filename, isIndented);
                api.name(file.filename.replace(this.EXT_REGEX, '.css'));
                api.content(result);
            }
            catch (e) {
                api.error(e);
            }
        });
    }
    compile(data, file, indentedSyntax) {
        return __awaiter(this, void 0, void 0, function* () {
            const result = yield promised_1.default(require('node-sass')).render({
                data,
                file,
                outFile: undefined,
                indentedSyntax,
                sourceMap: false,
                outputStyle: 'expanded'
            });
            return result.css.toString();
        });
    }
    testBlock(type, srcOrLang) {
        return !!(type === 'style' &&
            srcOrLang &&
            (srcOrLang === 'scss' ||
                srcOrLang === 'sass' ||
                this.EXT_REGEX.test(srcOrLang)));
    }
    processBlock(block, api) {
        return __awaiter(this, void 0, void 0, function* () {
            if ('src' in block.attrs) {
                block.attrs.src = block.attrs.src.replace(this.EXT_REGEX, '.css');
                api.addBlock('style', block.attrs);
                return;
            }
            const isIndented = block.lang === 'sass';
            try {
                api.addBlock('style', block.attrs, yield this.compile(block.content, block.filename, isIndented));
            }
            catch (e) {
                api.error(e);
            }
        });
    }
}
exports.default = SassPlugin;
