"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs");
const prettier = require('prettier');
const promised_1 = require("@znck/promised");
function all(promises) {
    return __awaiter(this, void 0, void 0, function* () {
        return Promise.all(promises);
    });
}
exports.all = all;
function e(any) {
    const prefix = 'const __ = ';
    const source = prefix + JSON.stringify(any);
    const code = prettier.format(source, { semi: false, singleQuote: true }).trim();
    return code.substr(prefix.length);
}
exports.e = e;
function resolveExternal(context, query, extensions) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!context)
            return;
        const dir = path.dirname(context);
        const filename = path.resolve(dir, query);
        if (yield promised_1.default(fs).exists(filename)) {
            return filename;
        }
        for (const ext of extensions) {
            const filename = path.resolve(dir, query + '.' + ext);
            if (yield promised_1.default(fs).exists(filename)) {
                return filename;
            }
        }
    });
}
exports.resolveExternal = resolveExternal;
function flatten(args) {
    const result = [];
    for (const arg of args) {
        if (Array.isArray(arg)) {
            result.push.apply(result, flatten(arg));
        }
        else if (arg) {
            result.push(arg);
        }
    }
    return result;
}
exports.flatten = flatten;
function read(filename) {
    return __awaiter(this, void 0, void 0, function* () {
        const content = yield promised_1.default(fs).readFile(filename);
        return content.toString();
    });
}
exports.read = read;
function write(filename, content, overwrite = false) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!overwrite && (yield promised_1.default(fs).exists(filename)))
            throw Error('Error: ' + filename + ' already exists.');
        yield mkdirp(path.dirname(filename));
        yield promised_1.default(fs).writeFile(filename, content);
    });
}
exports.write = write;
function mkdirp(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!(yield promised_1.default(fs).exists(dir))) {
            yield mkdirp(path.dirname(dir));
            try {
                yield promised_1.default(fs).mkdir(dir);
            }
            catch (e) {
                if (!/file already exists/i.test(e.message)) {
                    throw e;
                }
            }
        }
    });
}
exports.mkdirp = mkdirp;
